/* ######################################################################### */
/* ##                                                                     ## */
/* ##  D B T U T O O L S / C O R E / O S / S Y S T E M . J A V A          ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Job .......: Class providing Operating System related methods.     ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Copyright (C) 2002  Daniel Scheibli                                ## */
/* ##                                                                     ## */
/* ##  This library is free software; you can redistribute it and/or      ## */
/* ##  modify it under the terms of the GNU Lesser General Public         ## */
/* ##  License as published by the Free Software Foundation; either       ## */
/* ##  version 2.1 of the License, or (at your option) any later version. ## */
/* ##                                                                     ## */
/* ##  This library is distributed in the hope that it will be useful,    ## */
/* ##  but WITHOUT ANY WARRANTY; without even the implied warranty of     ## */
/* ##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU  ## */
/* ##  Lesser General Public License for more details.                    ## */
/* ##                                                                     ## */
/* ##  You should have received a copy of the GNU Lesser General Public   ## */
/* ##  License along with this library; if not, write to the Free         ## */
/* ##  Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,     ## */
/* ##  MA 02111-1307 USA                                                  ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Remark ....: <none>                                                ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Author ....: Daniel Scheibli <daniel.scheibli@edelbyte.org>        ## */
/* ##  Date ......: 2003-01-15                                            ## */
/* ##  Changes ...: ----- System.java V00.99/R020 ----------------------- ## */
/* ##               <none>                                                ## */
/* ##                                                                     ## */
/* ######################################################################### */



/* ##### Presettings */
/* ------------------------------------------------------------------------- */
package org.dbtutools.DbtuTools.core.os;
/* ------------------------------------------------------------------------- */





/* ##### Class definition */
/** ************************************************************************
 * The <code>System</code> class provides operating system related stuff.
 * It cannot be instantiated.
 * @author Daniel Scheibli &lt;daniel.scheibli at edelbyte.org&gt;
 * ************************************************************************* */
public class System
{
 /* ##### Presettings (class fields) */
 /* ------------------------------------------------------------------------ */
 /** ***********************************************************************
  * Constant standing for all DOS succession operating systems, like
  * the Microsoft Windows family and IBM's OS/2.
  * ************************************************************************ */
 public static final int OS_FAMILY_WINTEL = 0; 
 /** ***********************************************************************
  * Constant standing for the Unix operating systems, like IBM's AIX,
  * Linux, Sun Solaris and others.
  * ************************************************************************ */
 public static final int OS_FAMILY_UNIX   = 1;
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -- */ 
 /** ***********************************************************************
  * Constant standing for all little endian platforms as systems
  * with Intel x86 processor(s) are.
  * ************************************************************************ */ 
 public static final int ENDIAN_TYPE_LITTLE = 0; 
 /** ***********************************************************************
  * Constant standing for all big endian platforms as most
  * RISC machines are.
  * ************************************************************************ */ 
 public static final int ENDIAN_TYPE_BIG    = 1; 
 /* ------------------------------------------------------------------------ */ 





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   S Y S T E M ()                                                   ## */
 /* ##                                                                    ## */ 
 /* ######################################################################## */
 /** ***********************************************************************
  * Private declared Constructor, preventing the instantiation
  * of the <code>System</code> class.
  * ************************************************************************ */
 private System( )
 { }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   G E T E N D I A N T Y P E ()                                     ## */ 
 /* ##                                                                    ## */
 /* ######################################################################## */ 
 /** ***********************************************************************
  * Detects and returns the endian type of the current running
  * platform.<br />
  * <br />  
  * <i>Background:</i> The detection is done by calling the
  * {@link org.dbtutools.DbtuTools.core.ApiWrapper#getEndianType()} method.
  *
  * @return {@link #ENDIAN_TYPE_LITTLE} - For the case, that a
  *         little endian platform was detected.
  *         <br>
  *         {@link #ENDIAN_TYPE_BIG} - For the case, that a
  *         big endian platform was detected.
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the endian type could
  *            not be detected.<BR>
  * ************************************************************************ */
 public static int getEndianType( ) throws org.edelbyte.util.UnknownValueException
 {
  /* ##### Detect, map and return the endian type */
  /* ----------------------------------------------------------------------- */ 
  switch( org.dbtutools.DbtuTools.core.ApiWrapper.getEndianType() )
  {
   case org.dbtutools.DbtuTools.core.ApiWrapper.ENDIAN_TYPE_LITTLE:
        return( ENDIAN_TYPE_LITTLE );
   case org.dbtutools.DbtuTools.core.ApiWrapper.ENDIAN_TYPE_BIG:
        return( ENDIAN_TYPE_BIG );
   default:
        throw new org.edelbyte.util.UnknownValueException( "Endian type is unknown" );
  }
  /* ----------------------------------------------------------------------- */ 
 }
 
 
 
 

 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   G E T O S F A M I L Y ()                                         ## */ 
 /* ##                                                                    ## */
 /* ######################################################################## */ 
 /** ***********************************************************************
  * Detects and returns the operating system family.<br />
  * <br />
  * <i>Background:</i> The detection is done by calling the
  * {@link org.edelbyte.util.System#getOsFamily()} method.
  *
  * @return {@link #OS_FAMILY_UNIX} - For the case, that a
  *         Unix family operating system was detected.
  *         <br>
  *         {@link #OS_FAMILY_WINTEL} - For the case, that a
  *         Wintel family operating system was detected.
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the operating system family could
  *            not be detected.<BR>
  * ************************************************************************ */
 public static int getOsFamily( ) throws org.edelbyte.util.UnknownValueException
 {
  /* ##### Detect, map and return the operating system family */
  /* ----------------------------------------------------------------------- */ 
  switch( org.edelbyte.util.System.getOsFamily() )
  {
   case org.edelbyte.util.System.OS_FAMILY_UNIX:
        return( OS_FAMILY_UNIX );
   case org.edelbyte.util.System.OS_FAMILY_WINTEL:	
        return( OS_FAMILY_WINTEL );
   default:
        throw new org.edelbyte.util.UnknownValueException( "Operating system family is unknown" );
  }
  /* ----------------------------------------------------------------------- */ 
 }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   G E T P A R E N T P R O C E S S I D ()                           ## */ 
 /* ##                                                                    ## */
 /* ######################################################################## */ 
 /** ***********************************************************************
  * Detects and returns the Parent Process ID (identifies the
  * caller of the Java program).<br />
  * <br />
  * <i>Background:</i> The detection is done by interpreting the
  * value of <code>java.lang.System.getProperty(&quot;PPID&quot;);
  *
  * @return The Process ID of the parent program.
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the Parent Process ID
  *            could not be detected.<BR>
  * ************************************************************************ */
 public static int getParentProcessId( ) throws org.edelbyte.util.UnknownValueException
 {
  /* ##### Presettings */
  /* ----------------------------------------------------------------------- */ 
  java.lang.String oParentPid = java.lang.System.getProperty( "PPID" );
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
  int              iParentPid;  
  /* ----------------------------------------------------------------------- */   



  /* ##### Check and process the value */
  /* ----------------------------------------------------------------------- */
  try
  { iParentPid = java.lang.Integer.parseInt( oParentPid ); }
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */  
  catch( java.lang.NumberFormatException oException )
  { throw new java.lang.NumberFormatException( "Environment variable PPID was not set or contains no value." ); }
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
  return( iParentPid );  
  /* ----------------------------------------------------------------------- */
 }
}
/* ------------------------------------------------------------------------- */




